SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84
This commit is contained in:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
zatwierdzone przez GitHub
rodzic 7b0ed9e8d3
commit 5da168300f
14 zmienionych plików z 47 dodań i 47 usunięć
@@ -23,6 +23,6 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern "C" __global__ void hello_world(float* a, float* b) {
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
b[tx] = a[tx];
}